<?php
/** functions.php for folder 'wp-content/plugins/xilidev-libraries' (copy and paste those none present if the file exists) 
 * 
 *	© dev.xiligroup.com 2010-02-27 
 *
 * NOTE : if you want (gold options not activated), you can also add (and personnalize) these functions in functions.php of current theme (be aware of naming functions)
 */
 
/**
 * shortcode to insert link to post in other languages inside the content 
 * example : [linkpost lang="fr_FR"]link to french similar post[/linkpost] (if title="some text" : title of link is set by replacing title 'A similar post in...')
 *
 *
 *@since 1.2
 */
function xiliml_build_linked_posts_shortcode($atts,$content=null) {
	global $post;
	$arr_result = shortcode_atts(array('lang'=>'','title'=>''), $atts);
	extract($arr_result);
	$language = xiliml_get_language($lang); /* test if lang is available */
	
	if ($language !== false) {
		$otherpost = get_post_meta($post->ID, 'lang-'.$language->slug, true);
	}
	
	if ($otherpost) {
		if ('' == $title) {
			$obj_lang = xiliml_get_lang_object_of_post($otherpost);
			if (false !== $obj_lang) {
				$description = $obj_lang->description;
				$title = __('A similar post in',THEME_TEXTDOMAIN).' '.$description;
			} else {
				$title = __('Error with target post #',THEME_TEXTDOMAIN).$otherpost;
			}
		}
		$output = '<a href="'.get_permalink($otherpost).'" title="'.$title.'">'.$content.'</a>';
		/* this link above can be enriched by image or flag */
	} else {
		$output = '<a href="#" title="'.__('Error: other post not present !!!','xili-language').'">'.$content.'</a>';
	}
	return $output;
}
add_shortcode('linkpost', 'xiliml_build_linked_posts_shortcode');

/**
 * examples of filters for protected / private posts : for translated password form and labels...
 *
 * don't forgot to update your .po (.mo) !!!
 *
 * @since 1.1.8 (compatible with previous)
 *
 */
function xiliml_get_excerpt ($output='') {
	global $post;
	if (post_password_required($post)) {
		$output = __('There is no excerpt because this is a protected post.',THEME_TEXTDOMAIN);
	}
	return $output;
}
add_filter('the_excerpt', 'xiliml_get_excerpt'); //get_the_excerpt filter unusable...

function xiliml_protected_title ($text='') {
	return __('Protected: %s',THEME_TEXTDOMAIN);
}
add_filter('protected_title_format', 'xiliml_protected_title');

function xiliml_private_title ($text='') {
	return __('Private: %s',THEME_TEXTDOMAIN);
}
add_filter('private_title_format', 'xiliml_private_title');

function xiliml_the_password_form($output) {
	global $post;
	$label = 'pwbox-'.(empty($post->ID) ? rand() : $post->ID);
	$output = '<form action="' . get_option('siteurl') . '/wp-pass.php" method="post">
	<p>' . __("This post is password protected. To view it please enter your password below:",THEME_TEXTDOMAIN) . '</p>
	<p><label for="' . $label . '">' . __("Password:",THEME_TEXTDOMAIN) . ' <input name="post_password" id="' . $label . '" type="password" size="20" /></label> <input type="submit" name="Submit" value="' . __("Submit",THEME_TEXTDOMAIN) . '" /></p>
	</form>
	';
	return  $output;
}
add_filter('the_password_form','xiliml_the_password_form');

/**
 * Date formats converter  of date() vs of strftime() used by xili-language to translate live dates and times...
 *
 * @param a string as format in date()
 * @return a string as format in strftime()
 */
function xiliml_time_format_translator ($phpformat = 'm/d/Y H:i') {
	/* order left to right to avoid over replacing */
	$phpformchar = array('A' ,'a' ,'D' ,'l' ,'g' ,'d' ,'j' ,'z' ,'N' ,'w ','W' ,'M' ,'F' ,'h' ,'M ','m' ,'y' ,'Y' ,'H' ,'G' ,'i' ,'S' ,'s' ,'O');
	/* doc here: http://fr2.php.net/manual/en/function.date.php */
	$locformchar = array('%p','%P','%a','%A','%l','%d','%e','%j','%U','%w','%W','%b','%B','%I','%h','%m','%y','%Y','%H','%G','%M', '','%S','%z');
	/* doc here: http://fr.php.net/manual/en/function.strftime.php */
	
	/* another example without using str_replace for theme with few date formats
	switch ($phpformat) {
  	case 'M' :
  		$localeformat = '%b'; // if server is well configured (setlocale), no need to translate word of months, or weekdays....
  		break;
  	case 'j' :	
  		$localeformat = '%d'; 
  		break;
  	case 'm j, Y' :
  		$localeformat = '%B %d, %Y'; // this string as msgid is to translate in .po as msgstr ("%d %B %Y" in fr_FR)
  		break;
  	case 'H:i' :
  		$localeformat = '%H:%M';
  		break;
  	default:
  	$localeformat = '%B %d, %Y - %H:%M';	
  	}	
   	//return $localeformat;
   */
   if ('' == $phpformat) $phpformat = 'm/d/Y H:i';
   
   return str_replace($phpformchar, $locformchar, $phpformat);
}

/* filter for template tag: get_comment_date() */
function xiliml_comment_date($comment_time,$theformat = '') {
  /* first param no used because translated by WP_LANG php format */
  /* the first param is to be as msgid in .po example: %B %d, %Y - %H:%M or %B %d, %Y at %H:%M   */	
  echo $theformat;
  $format = xiliml_time_format_translator ($theformat);
  return the_xili_local_time($format, strtotime(get_comment_time ('m/d/Y H:i'))); 
  /* impossible to use get_comment_date as it is itself filtered*/
}
add_filter('get_comment_date','xiliml_comment_date',10,2);

/* filter for template tag: the_time() */
function xiliml_date($thetime, $theformat) {
  /* first param no used because translated by WP_LANG php format */
  //echo $theformat;
  //print_r(date_parse_from_format ($theformat, $thetime));
  $format = xiliml_time_format_translator ($theformat);
   
  return the_xili_local_time($format,strtotime(get_the_time('m/d/Y H:i')));
}
add_filter('the_time','xiliml_date',10,2);

/* filter for template tag: the_modified_time() */
function xiliml_modified_date($thetime,$theformat) {
	/* first param no used because translated by WP_LANG php format */
 
  	$format = xiliml_time_format_translator ($theformat);	

  return the_xili_local_time($format,strtotime(get_the_modified_time('m/d/Y H:i')));
}
add_filter('the_modified_time','xiliml_modified_date',10,2);


/**
 * here insert your own functions file inside xilidev-libraries folder 
 *
 * un-comment or add your lines below !
 */
if (file_exists(XILIFUNCTIONSPATH . '/gold-functions.php')) 
	require_once (XILIFUNCTIONSPATH . '/gold-functions.php'); /* wp_head, undefined */
	
// if (file_exists(XILIFUNCTIONSPATH . '/my-functions.php')) 
	// require_once (XILIFUNCTIONSPATH . '/my-functions.php'); /* my-functions */	
?>